Exception: Abstractify::AbstractMethodMustOverrideError

Inherits:
AbstractMethodError show all
Defined in:
lib/abstractify/abstract.rb

Instance Method Summary collapse

Constructor Details

#initialize(msg = "Can't instantiate abstract class because some of its abstract methods were not overridden") ⇒ AbstractMethodMustOverrideError

Returns a new instance of AbstractMethodMustOverrideError.



21
22
23
# File 'lib/abstractify/abstract.rb', line 21

def initialize(msg="Can't instantiate abstract class because some of its abstract methods were not overridden")
  super
end